<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <location filename="../about.cpp" line="53"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>Interfaz gráfica para aplicar diversos ajustes útiles</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>launches brightness-systray</source>
        <translation>activar bandeja de brillo</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>abre con la pestaña de visualización abierta. Solo válido con el escritorio Xfce en ejecución</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>Abre la pestaña del tema directamente. Válido en escritorios Xfce y Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Display additional debug output in console</source>
        <translation>Mostrar salida de depuración adicional en la consola</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation>Abre directamente la pestaña Otros. Válido en todos los escritorios</translation>
    </message>
</context>
<context>
    <name>Tweak</name>
    <message>
        <location filename="../tweak.ui" line="14"/>
        <location filename="../tweak.cpp" line="72"/>
        <location filename="../tweak.cpp" line="233"/>
        <location filename="../tweak.cpp" line="252"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="33"/>
        <source>Xfce Panel</source>
        <translation>Panel Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="39"/>
        <location filename="../tweak.ui" line="233"/>
        <location filename="../tweak.ui" line="520"/>
        <location filename="../tweak.ui" line="599"/>
        <location filename="../tweak.ui" line="655"/>
        <location filename="../tweak.ui" line="682"/>
        <location filename="../tweak.ui" line="874"/>
        <location filename="../tweak.ui" line="1265"/>
        <location filename="../tweak.ui" line="1394"/>
        <location filename="../tweak.ui" line="1441"/>
        <location filename="../tweak.ui" line="1691"/>
        <source>Apply</source>
        <extracomment>apply changes</extracomment>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="58"/>
        <source>Tasklist</source>
        <translation>Lista de tareas</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="64"/>
        <source>Set Tasklist plugin to:</source>
        <translation>Establecer complemento lista de tareas como:</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="71"/>
        <source>Docklike is the modern dock plugin for the panel. Window Buttons is the classic tasklist without dock features.</source>
        <translation>Docklike es el complemento de dock moderno para el panel. Window Buttons es la lista de tareas clásica sin funciones de dock.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="78"/>
        <source>Tasklist Options</source>
        <translation>Opciones de la lista de tareas</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="85"/>
        <source>Docklike Options</source>
        <translation>Opciones del Docklike</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="95"/>
        <source>Affects 1st Panel</source>
        <translation>Afecta al 1.er panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="101"/>
        <location filename="../tweak.ui" line="1048"/>
        <location filename="../tweak.ui" line="1158"/>
        <location filename="../tweak.ui" line="1285"/>
        <source>Placement</source>
        <translation>Ubicación</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="114"/>
        <source>Backup/Restore Configuration (all panels)</source>
        <translation>Copia de seguridad/Restaurar la configuración (todos los paneles)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="127"/>
        <source>Backup current panel configuration</source>
        <translation>Respaldar configuración del panel actual</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="141"/>
        <source>Restore selected panel configuration</source>
        <translation>Restaurar la configuración seleccionada del panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="148"/>
        <source>Restore default panel</source>
        <translation>Restablecer panel por defecto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="158"/>
        <source>Panel Plugin Scales</source>
        <translation>Escalas del complemento Panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="164"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>Volúmen</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="184"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>Gestor de energía</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="221"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="227"/>
        <source>Theme Options</source>
        <translation>Opciones de Tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="262"/>
        <source>Remove User Theme Set</source>
        <translation>Eliminar el conjunto de temas de usuario</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="275"/>
        <source>Themes</source>
        <translation>Temas</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="281"/>
        <source>Application</source>
        <extracomment>theme an application will get</extracomment>
        <translation>Aplicaciones</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="301"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Toggle Dark Mode for GTK4 libadwaita applications&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Alternar el modo oscuro para aplicaciones GTK4 libadwaita&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="304"/>
        <source>Dark Mode</source>
        <translation>Modo oscuro</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="311"/>
        <location filename="../tweak.ui" line="1754"/>
        <source>Window Manager</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>Gestor de ventanas</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="331"/>
        <source>Legacy Styles</source>
        <translation>Estilos heredados</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="344"/>
        <source>Icons</source>
        <extracomment>icon theme</extracomment>
        <translation>Iconos</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="351"/>
        <source>Cursors</source>
        <extracomment>cursor theme</extracomment>
        <translation>Cursores</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="358"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>Guardar la configuración actual como un conjunto de temas</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="368"/>
        <source>Size</source>
        <extracomment>size of the cursor</extracomment>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="378"/>
        <source>default</source>
        <extracomment>default cursor size determined by X server</extracomment>
        <translation>por defecto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="401"/>
        <location filename="../tweak.ui" line="453"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="413"/>
        <source>Changing the VBlank mode may help alleviate some screen tearing issues. See Help for more information.</source>
        <translation>Cambiar el modo VBlank puede ayudar a aliviar algunos problemas de rotura de pantalla. Consulte la Ayuda para obtener más información.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="416"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="424"/>
        <source>auto</source>
        <translation>automático</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="429"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="434"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="439"/>
        <location filename="../tweak.ui" line="1022"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>apagado</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="447"/>
        <source>Transparency and shadow options</source>
        <translation>Opciones de transparencias y sombras</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="463"/>
        <source>Xfce Compositor Settings</source>
        <translation>Ajustes del Compositor de Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="466"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm Ajustes</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="476"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Lanzar herramienta de configuración compton-conf</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="479"/>
        <source>Picom settings</source>
        <translation>Configuración de Picom</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="490"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Editar compton.conf directamente en editor de texto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="493"/>
        <source>Edit picom.conf</source>
        <translation>Editar picom.conf</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="540"/>
        <source>Display</source>
        <translation>Pantalla</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="546"/>
        <source>Display Tweaks</source>
        <translation>Retoques de visualización</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="552"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>Luz de fondo de hardware</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="575"/>
        <location filename="../tweak.ui" line="706"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="582"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>Escala GTK</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="635"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>Elija mostrar ajustes de xrandr</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="645"/>
        <source>Resolution</source>
        <translation>Resolución</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="662"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>Escala xrandr</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="689"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>Programa (xrandr) Brillo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="713"/>
        <source>Saving is per display</source>
        <translation>El guardado se aplica por pantalla.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="716"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="740"/>
        <source>Xfce</source>
        <translation>Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="746"/>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="752"/>
        <source>Enable single-click on desktop</source>
        <translation>Habilitar un solo clic en el escritorio</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="759"/>
        <source>Enable Desktop Zoom </source>
        <translation>Habilitar ampliación de escritorio</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="766"/>
        <location filename="../tweak.ui" line="1355"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Mostrar ventanas de todas las áreas de trabajo en el panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="773"/>
        <source>Do not shorten file names on the desktop</source>
        <translation>No acortar los nombres de archivo en el escritorio.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="783"/>
        <source>Thunar</source>
        <translation>Thunar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="789"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Habilitar un solo clic en el gestor de archivos Thunar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="796"/>
        <source>Reset custom right-click actions to system defaults</source>
        <translation>Restablecer las acciones personalizadas del botón derecho del ratón a los valores predeterminados del sistema.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="803"/>
        <source>Thunar windows always open in split view</source>
        <translation>Abrir siempre las ventanas de Thunar en vista dividida</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="810"/>
        <source>Thunar split view opens horizontal</source>
        <translation>Abrir vista dividida de Thunar en horizontal</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="820"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Mostrar porcentajes en las notificaciones cuando estén disponibles</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="827"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Mostrar los botones de acción del diálogo de archivos GTK, en la parte inferior de los diálogos</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="834"/>
        <source>(also turns off Client Side Decorations for Xfce applications)</source>
        <translation>(también desactiva las decoraciones del lado del cliente para las aplicaciones Xfce)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="844"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Habilitar Hibernar en el menú de Salida</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="851"/>
        <source>note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>Nota: para hibernar, el SWAP debe ser &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="885"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="891"/>
        <location filename="../tweak.ui" line="1365"/>
        <source>Reset Defaults</source>
        <translation>Restablecer ajustes</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="897"/>
        <source>Reset DefaultDock</source>
        <translation>Restablecer DefaultDock</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="904"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Reiniciar menú de Fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="911"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Restablecer TODOS los ajustes de mx-fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="918"/>
        <source>Add new default menu items, if any, to existing fluxbox menu.</source>
        <translation>Añadir nuevos elementos de menú por defecto, si los hay, al menú Fluxbox existente.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="921"/>
        <source>Upgrade existing menu entries</source>
        <translation>Actualizar entradas de menú existentes</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="931"/>
        <source>Desktop Icons</source>
        <translation>Iconos de escritorio</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="937"/>
        <source>Toggle desktop icons</source>
        <translation>Des/Activar iconos del escritorio</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="945"/>
        <location filename="../tweak.ui" line="969"/>
        <source>On</source>
        <translation>Encendido</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="950"/>
        <location filename="../tweak.ui" line="974"/>
        <source>Off</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="958"/>
        <source>Toggle icon captions</source>
        <translation>Des/Activar subtítulos de iconos</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="979"/>
        <source>On Hover</source>
        <translation>Al cubrir con el puntero del ratón</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1006"/>
        <source>Screensaver</source>
        <translation>Salvapantallas</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1012"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation>Tiempo de inactividad (minutos)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1035"/>
        <source>Toolbar Settings</source>
        <translation>Ajustes de la Barra de herramientas</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1041"/>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1122"/>
        <location filename="../tweak.ui" line="1232"/>
        <source>Autohide</source>
        <translation>Auto ocultar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1129"/>
        <source>Show Toolbar</source>
        <translation>Mostrar barra de herramientas</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1136"/>
        <source>Width</source>
        <translation>Ancho</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1152"/>
        <source>Dock Settings</source>
        <translation>Ajustes del Dock</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1239"/>
        <source>Manage Tint2 Panel</source>
        <translation>Gestionar panel Tint2</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1273"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1279"/>
        <source>Affects 1st panel</source>
        <translation>Afecta el 1er panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1296"/>
        <source>Bottom</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1301"/>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1306"/>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1311"/>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1335"/>
        <source>Workspace</source>
        <translation>Áea de trabajo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1341"/>
        <source>Autostart plasma-discover system tray update notification utility</source>
        <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
        <translation>inicio automático de la Utilidad de notificación de actualización en la bandeja del sistema plasma-discover</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1348"/>
        <source>Enable single-click</source>
        <translation>Habilitar un sólo click</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1371"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Restablecer valores predeterminados de KDE/Plasma</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1405"/>
        <source>Super Key</source>
        <extracomment>referring to the meta or Left Super Key</extracomment>
        <translation>Tecla Super izd.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1411"/>
        <source>Also known as the &quot;windows&quot; key</source>
        <translation>También conocida como la tecla &quot;Windows&quot;</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1414"/>
        <source>Command to run with Super (Meta) key</source>
        <extracomment>label for the field to enter the command to use with super key</extracomment>
        <translation>Comando para ejecutar con la tecla Super (Meta)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1424"/>
        <source>xfce-superkey defaults</source>
        <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
        <translation>Por defecto xfce-superkey</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1431"/>
        <source>Choose application</source>
        <extracomment>description of button action to launch file dialog to choose an application</extracomment>
        <translation>Seleccionar aplicación</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1462"/>
        <source>Miscellaneous</source>
        <translation>Miscelánea</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1468"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Restablecer Lightdm (pantalla de inicio) a la tema predeterminada</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1475"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Habilitar montar discos internos por usuarios no-root</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1482"/>
        <source>Enable kernel sandbox</source>
        <translation>Habilitar caja de arena del kernel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1489"/>
        <source>requires reboot</source>
        <translation>requiere reiniciar el ordenador</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1492"/>
        <source>Enable Bluetooth adapters on boot</source>
        <translation>Habilitar adaptadores Bluetooth en el arranque</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1499"/>
        <source>Enable Bluetooth battery info for connected devices (requires system restart)</source>
        <extracomment>expose battery info for connected bluetooth devices to the operating system via dbus</extracomment>
        <translation>Activar la información de la batería bluetooth para los dispositivos conectados (requiere reiniciar el sistema)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1506"/>
        <source>Early loading of KVM module is new to  kernel 6.12 and conflicts with some non-KVM virtual machine applications, including virtualbox</source>
        <extracomment>early loading is new on 6.12 kernel and conflicts with virtualbox</extracomment>
        <translation>La carga anticipada del módulo KVM es nueva en el kernel 6.12 y entra en conflicto con algunas aplicaciones de máquina virtual que no son KVM, incluida virtualbox.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1509"/>
        <source>Disable early KVM module load (must be disabled for Virtualbox operation on kernel 6.12 and up)</source>
        <extracomment>disable early loading of KVM module.  necessary for virtualbox to function with kernels 6.12 and up.  actually default behavior on kernels 6.11 and earlier.</extracomment>
        <translation>Desactivar la carga anticipada de módulos KVM (debe desactivarse para el funcionamiento de Virtualbox en kernel 6.12 y superiores)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1516"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt instala paquetes adicionales &quot;recommends&quot; como dependencias</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1523"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation>Generar el menú Fluxbox de todas las aplicaciones después de la instalación, eliminación y actualización de paquetes</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1530"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Usar decoraciones del lado del cliente (CSD) en aplicaciones GTK3 que las admitan (requiere reiniciar la sesión) </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1537"/>
        <source>put a hold or remove a hold on updates of Liquorix kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>poner una retención o quitar una retención en las actualizaciones de los kernels de Liquorix</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1540"/>
        <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Habilitar Actualizaciones Automáticas del Kernel Liquorix (repositorio MX ahs)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1547"/>
        <source>put a hold or remove a hold on updates of Debian  kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>poner una retención o quitar una retención en las actualizaciones de los kernels de Debian</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1550"/>
        <source>Enable Automatic Debian Kernel Updates</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Habilitar actualizaciones automáticas del kernel de Debian</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1557"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Usar el controlador Intel en lugar del controlador predeterminado &quot;modesetting&quot; (requiere reiniciar)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1583"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>NOTA: el archivo actual /etc/X11/xorg.conf.d/20-intel.conf será respaldado en la carpeta /home</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1590"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Use la opción tearfree amdgpu</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1597"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>NOTA: el archivo actual /etc/X11/xorg.conf.d/20-amd.conf será respaldado en la carpeta /home</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1604"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Use la opción tearfree del controlador radeon</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1611"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>NOTA: el archivo actual /etc/X11/xorg.conf.d/20-radeon.conf será respaldado en la carpeta /home</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1618"/>
        <source>Change computer name (requires reboot)</source>
        <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
        <translation>Cambiar el nombre del ordenador (requiere reiniciar)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1628"/>
        <source>Change Default Display Manager (login screen) (requires reboot)</source>
        <extracomment>option to change display manager login screen.  present if more than one display manager is installed</extracomment>
        <translation>Cambiar el Administrador de Pantalla predeterminado (pantalla de inicio de sesión) (requiere reiniciar el sistema)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1641"/>
        <source>Password for administrative tasks:</source>
        <translation>Contraseña para tareas administrativas:</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1648"/>
        <source>&amp;User</source>
        <translation>&amp;Usuario</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1655"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1705"/>
        <source>Xfce Settings</source>
        <translation>Xfce Ajustes</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1711"/>
        <source>Customize the panel</source>
        <translation>Personalizar el panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1721"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1741"/>
        <source>Configure window behavior and shortcuts</source>
        <translation>Configurar el comportamiento de las ventanas y los atajos</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1774"/>
        <source>Customize the look of your desktop</source>
        <translation>Personalizar la apariencia de tu escritorio</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1787"/>
        <source>Appearance</source>
        <translation>Aparencia</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1799"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1809"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1867"/>
        <source>Quit application</source>
        <translation>Salir de la aplicación</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1870"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1876"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="73"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--interruptor de la pantalla solo válido para Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="232"/>
        <source>About MX Tweak</source>
        <translation>Acerca de MX Ajustes</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="234"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="235"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>App para cambios rápidos al tema de la IU por defecto y ajustes</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="237"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Derechos de autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="238"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="252"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
</context>
<context>
    <name>TweakCompositor</name>
    <message>
        <location filename="../tweak_compositor.cpp" line="62"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="63"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) Compositor</translation>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="64"/>
        <source>Picom</source>
        <translation>Picom</translation>
    </message>
</context>
<context>
    <name>TweakMisc</name>
    <message>
        <location filename="../tweak_misc.cpp" line="281"/>
        <source>Please enter a computer name.</source>
        <comment>question to enter a name for the computer hostname</comment>
        <translation>Por favor ingrese un nombre de computadora.</translation>
    </message>
    <message>
        <location filename="../tweak_misc.cpp" line="285"/>
        <source>Sorry, your computer name contains invalid characters.
You'll have to select a different
name before proceeding.</source>
        <comment>unacceptable characters are found in hostname, pick a new name</comment>
        <translation>Lo sentimos, el nombre que eligió para su equipo contiene caracteres inválidos. Deberá seleccionar un nombre diferente para continuar.</translation>
    </message>
</context>
<context>
    <name>TweakSuperKey</name>
    <message>
        <location filename="../tweak_superkey.cpp" line="43"/>
        <source>Select application to run</source>
        <comment>will show in file dialog when selection an application to run</comment>
        <translation>Seleccione la aplicación a ejecutar</translation>
    </message>
</context>
<context>
    <name>TweakTheme</name>
    <message>
        <location filename="../tweak_theme.cpp" line="64"/>
        <source>Plasma Widget Themes</source>
        <comment>theme style of the kde plasma widgets</comment>
        <translation>Temas de widgets de Plasma</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="65"/>
        <source>Color Schemes</source>
        <comment>plasma widget color schemes</comment>
        <translation>Esquemas de color</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="66"/>
        <source>Plasma Look &amp; Feel Global Themes</source>
        <comment>plasma global themes</comment>
        <translation>Temas globales de apariencia de Plasma</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="139"/>
        <source>Choose a theme set</source>
        <translation>Elegir un conjunto de temas</translation>
    </message>
</context>
<context>
    <name>TweakXfcePanel</name>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="17"/>
        <source>Horizontal (Bottom)</source>
        <translation>Horizontal (Abajo)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="18"/>
        <source>Horizontal (Top)</source>
        <translation>Horizontal (Arriba)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="20"/>
        <source>Vertical (Left)</source>
        <translation>Vertical (Izquierda)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="21"/>
        <source>Vertical (Right)</source>
        <translation>Vertical (Derecha)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="23"/>
        <source>docklike</source>
        <translation>docklike</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Botones de ventanas</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="273"/>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <location filename="../tweak_xfce_panel.cpp" line="297"/>
        <location filename="../tweak_xfce_panel.cpp" line="301"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>Plese remove special characters</source>
        <translation>Por favor, remueva los caracteres especiales.</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>from file name</source>
        <translation>del nombre del archivo</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <source>File name already exists.  Choose another name</source>
        <translation>El nombre del archivo ya existe. Elija otro nombre</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="298"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>El archivo no es un archivo comprimido tar.xz válido</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="302"/>
        <source>Archive does not contain a panel config</source>
        <translation>El archivo no contiene una configuración de panel</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Ventana Principal</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="34"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="41"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Programa (xrandr) Brillo</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="61"/>
        <location filename="../brightness_small.ui" line="89"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="68"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="75"/>
        <source>Hardware Backlight</source>
        <translation>Luz de fondo de hardware</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="35"/>
        <source>MX-Tweak</source>
        <translation>MX-Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="54"/>
        <source>Display</source>
        <translation>Pantalla</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="59"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Eliminar el conjunto de temas de usuario</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nuevo conjunto de temas </translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Introduzca el nombre para el nuevo conjunto de temas</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="38"/>
        <source>Window Buttons</source>
        <translation>Botones de ventanas</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="23"/>
        <source>Appearance</source>
        <translation>Aparencia</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="29"/>
        <source>Show button labels</source>
        <translation>Mostrar etiquetas de los botones</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="36"/>
        <source>Show flat buttons</source>
        <translation>Mostrar botones planos</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="43"/>
        <source>Show handle</source>
        <translation>Mostrar asa</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="50"/>
        <source>Sorting Order:</source>
        <translation>Orden de selección:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="58"/>
        <source>Timestamp</source>
        <translation>Marca de tiempo</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="63"/>
        <source>Group title and timestamp</source>
        <translation>Título del grupo y marca de tiempo</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="68"/>
        <source>Window Title</source>
        <translation>Título de la ventana</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="73"/>
        <source>Group title and window title</source>
        <translation>Título del grupo y título de la ventana</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="78"/>
        <source>None, allow drag-and-drop</source>
        <translation>Ninguno, permitir arrastrar y soltar</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="89"/>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="95"/>
        <source>Window grouping:</source>
        <translation>Agrupar las ventanas:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="103"/>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="108"/>
        <source>Always</source>
        <translation>Siempre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="116"/>
        <source>Middle click action:</source>
        <translation>Acción del clic de al medio:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="124"/>
        <source>Nothing</source>
        <translation>Nada</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="129"/>
        <source>Close window</source>
        <translation>Cerrar ventana</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="134"/>
        <source>Minimize window</source>
        <translation>Minimizar ventana</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="142"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Restaurar ventanas minimizadas al área de trabajo activa</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="149"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Dibujar marco alrededor de la ventana al pasar por encima del botón</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="156"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>intercambiar ventanas usando la rueda del ratón</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="166"/>
        <source>Filtering</source>
        <translation>Filtrado</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="172"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Mostrar ventanas de todas las áreas de trabajo</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="179"/>
        <source>Show only minimized windows</source>
        <translation>Solo mostrar ventanas minimizadas</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="186"/>
        <source>Show windows from all monitors</source>
        <translation>Mostrar ventanas de todos los monitores</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="210"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="23"/>
        <source>Feature Settings</source>
        <translation>Ajustes de características</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="29"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Mostrar ventanas sobrepuestas directamente en pantalla plena</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="36"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Sincronizar dibujando área vertical en blanco</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="43"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Mostrar vista previa de ventanas en lugar de iconos durante el ciclo</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="50"/>
        <source>Show shadows under popup windows</source>
        <translation>Mostrar sombras debajo de ventanas desplegables</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="57"/>
        <source>Show shadows under dock windows</source>
        <translation>Mostrar sombras debajo de ventanas del muelle</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="64"/>
        <source>Show shadows under regular windows</source>
        <translation>Mostrar sombras debajo ventanas normales</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="74"/>
        <source>Opacity Settings</source>
        <translation>Ajustes de opacidad</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="80"/>
        <source>Window decorations</source>
        <translation>Decoraciones de ventanas</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="103"/>
        <source>Inactive windows</source>
        <translation>Ventanas inactivas</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="126"/>
        <source>Windows during move</source>
        <translation>Ventanas durante el movimiento</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="149"/>
        <source>Windows during resize</source>
        <translation>Ventanas durante redimensionar</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="172"/>
        <source>Popup Windows</source>
        <translation>Ventanas desplegables</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="205"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="25"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Ajustes del Compositor de Xfwm</translation>
    </message>
</context>
</TS>